﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.Data.Json;

namespace Accordion.Model
{
    public class AvailableOption
    {
        private const string displayKey = "display";
        private const string valueKey = "value";
        private const string indexKey = "index";

        private const string optionKey = "option";

        private string display;
        private string _value;
        private int index;

        public AvailableOption()
        {
            display = string.Empty;
            _value = string.Empty;
            index = 0;
        }

        public AvailableOption(JsonObject jsonObject) : this()
        {
            JsonObject inspectionItemObject = jsonObject.GetNamedObject(optionKey, null);
            if (inspectionItemObject != null)
            {
                Display = inspectionItemObject.GetNamedString(displayKey, "");
                Value = inspectionItemObject.GetNamedString(valueKey, "");

                var d = inspectionItemObject.GetNamedNumber(indexKey, 0.0);
                Index = Convert.ToInt32(d);
            }
        }

        public JsonObject ToJsonObject()
        {
            var availableItemJsonObject = new JsonObject();
            JsonObject optionItem = new JsonObject();

            availableItemJsonObject.SetNamedValue(indexKey, JsonValue.CreateNumberValue(Index));
            availableItemJsonObject.SetNamedValue(displayKey, JsonValue.CreateStringValue(Display));
            availableItemJsonObject.SetNamedValue(valueKey, JsonValue.CreateStringValue(Value));

            optionItem.Add(optionKey, availableItemJsonObject);
            return optionItem;
            //return availableItemJsonObject;
        }

        public string Display
        {
            get
            {
                return display;
            }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException("value");
                }
                display = value;
            }
        }

        public string Value
        {
            get
            {
                return _value;
            }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException("value");
                }
                _value = value;
            }

        }

        public int Index
        {
            get
            {
                return index;
            }
            set
            {
                index = value;
            }
        }

        public override string ToString()
        {
            return display;
        }
    }
}
